@@ -4,7 +4,7 @@ use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.18_16';
+  our $VERSION = '0.18_17';
 
   use Zydeco
     authority => 'cpan:SMONFF',
@@ -25,12 +25,9 @@ package Art::World {
   use Carp qw( carp cluck );
   use utf8;
   use Config::Tiny;
-  use DDP;
-  use Faker;
   use List::Util qw( max any );
   use Math::Round;
   use Try::Tiny;
-  use Types::XSD qw( DateTime );
 
   role Abstraction {
     has discourse ( type => Str );
@@ -127,7 +124,7 @@ package Art::World {
 
   role Event {
     has place ( type => Place );
-    has datetime ( type => DateTime );
+    has datetime ( type => InstanceOf['Time::Moment'] );
     # "guests"
     has participant ( type => ArrayRef[ Agent ] );
     has title ( type => Str, is => ro );
@@ -803,27 +800,6 @@ help consuming or implementing C<Art>.
 
 A specific kind of L<C<Playground>|Art::World/"Playground"> where you can build things tranquilly.
 
-=head1 META UTILS
-
-A couple of utilities that makes a sort of meta-programming very simple. It is
-more like a reminder for my bad memory than something very interesting. Largely
-inspired by L<this Perl Monks thread|https://www.perlmonks.org/?node_id=1043195>.
-
-  Art::World::Meta->get_all_attributes( $artist );
-  # ==>  ( 'id', 'name', 'reputation', 'artworks', 'collectors', 'collected', 'status' )
-
-=head2 get_class( Object $klass )
-
-Returns the class of the object.
-
-=head2 get_set_attributes_only( Object $clazz )
-
-Returns only attributes that are set for a particular object.
-
-=head2  get_all_attributes( Object $claxx )
-
-Returns even non-set attributes for a particular object.
-
 =head1 AUTHOR
 
 Sébastien Feugère <sebastien@feugere.net>
