@@ -1,6 +1,8 @@
 use 5.20.0;
 use strict;
 use warnings;
+use feature qw( postderef );
+no warnings qw( experimental::postderef );
 
 package Art::World::Util {
 
@@ -12,11 +14,7 @@ package Art::World::Util {
     }
   }
 
-  # Looks like the Art::World::Meta toolkit
-  # See also https://metacpan.org/pod/Class::MOP::Class for extreme cases
-  # my $meta = $self->meta;
   class Meta {
-    # TODO See also Zydeco's $class object
     method get_class( Object $klass ) {
       return ref $klass;
     }
@@ -36,12 +34,14 @@ package Art::World::Util {
     method random_set_of_agents ( Int $num ) { }
   }
 
+  # Makes possible to generate fake Persons very easily
   class Person {
+
     require Faker;
-    method fake_name {
-      my $f = Faker->new;
-      return $f->person_first_name . ' ' . $f->person_last_name;
-    }
+    has firstname ( isa => Str )     = $self->generator->person_first_name;
+    has lastname  ( isa => Str )     = $self->generator->person_last_name;
+    has generator ( isa => InstanceOf[ 'Faker' ] )  = Faker->new;
+    has fake_name ( isa => Str )     = $self->firstname .' '. $self->lastname;
 
     method generate_discourse( ArrayRef $buzz = [] ) {
       for ( 0 .. int rand( 3 )) { push $buzz->@*, Faker->new->company_buzzword_type1 };
@@ -54,6 +54,16 @@ package Art::World::Util {
       return join '', map { ucfirst lc $_ } split /(\s+)/, $token;
     }
   }
+
+  class Time {
+    require Time::Moment;
+    # YYYY-MM-DDThh:mm:ss
+    has source! (
+      isa =>
+      ( Str ) &
+      ( StrMatch[ qr/ \A \d{4} - \d{2} - \d{2} T \d{2} : \d{2} : \d{2} \z /x ] ));
+    has datetime ( isa => InstanceOf[ 'Time::Moment' ], lazy => true ) = Time::Moment->from_string( $self->source . 'Z' );
+  }
 }
 
 1;
@@ -86,6 +96,8 @@ the Art::World entities.
 
 =head3 Art::World::Math
 
+Artists usually don't like maths too much.
+
 =head4 pick()
 
 Pick an integer between a range that can be passed as a parameter. Mostly a way
@@ -93,11 +105,34 @@ to not have to memorize C<$min + int ( rand ( $max - $min ))>.
 
 =head3 Art::World::Meta
 
-=head4 get_class()
+Looks like the Art::World::Meta toolkit. See
+L<https://metacpan.org/pod/Class::MOP::Class> for extreme cases.
 
-=head4 get_set_attributes_only()
+  my $meta = $self->meta;
 
-=head4 get_all_attributes()
+Also there is the Zydeco's C<$class> object.
+
+This is a couple of utilities that makes a sort of meta-programming very simple. It is
+more like a reminder for my bad memory than something very interesting. Largely
+inspired by L<this Perl Monks thread|https://www.perlmonks.org/?node_id=1043195>.
+
+  Art::World::Meta->get_all_attributes( $artist );
+  # ==>  ( 'id', 'name', 'reputation', 'artworks', 'collectors', 'collected', 'status' )
+
+Mostly useless since Zydeco rely on Moo(se) so the Moose Meta Object Protocol is
+available.
+
+=head2 get_class( Object $klass )
+
+Returns the class of the object.
+
+=head2 get_set_attributes_only( Object $clazz )
+
+Returns only attributes that are set for a particular object.
+
+=head2  get_all_attributes( Object $claxx )
+
+Returns even non-set attributes for a particular object.
 
 =head3 Art::World::Person
 
@@ -109,6 +144,12 @@ Generate a complete person name using L<Faker>.
 
 =head4 titlify()
 
+=head3 Art::World::Time
+
+Handy way for generating a L<Time::Moment> object that can be used for C<Events> for example.
+
+  my $t = Art::World::Util->new_time( source => '2020-02-16T08:18:43' );
+
 =head1 AUTHOR
 
 Sébastien Feugère <sebastien@feugere.net>
